@@ -222,7 +222,7 @@ func TestAllTokens(t *testing.T) {
 		"+ += && = : , -- /\n/= $ @ == >= > >> ++ { [ < ( #\n" +
 		"<= ~ % %= * *= !~ ! != | || ^ ^= ** **= ? } ] ) ; - -= " +
 		"BEGIN break continue delete do else END exit " +
-		"for function getline if in next print printf return while " +
+		"for function getline if in next nextfile print printf return while " +
 		"atan2 close cos exp fflush gsub index int length log match rand " +
 		"sin split sprintf sqrt srand sub substr system tolower toupper " +
 		"x \"str\\n\" 1234\n" +
@@ -245,7 +245,7 @@ func TestAllTokens(t *testing.T) {
 		"+ += && = : , -- / <newline> /= $ @ == >= > >> ++ { [ < ( <newline> " +
 		"<= ~ % %= * *= !~ ! != | || ^ ^= ^ ^= ? } ] ) ; - -= " +
 		"BEGIN break continue delete do else END exit " +
-		"for function getline if in next print printf return while " +
+		"for function getline if in next nextfile print printf return while " +
 		"atan2 close cos exp fflush gsub index int length log match rand " +
 		"sin split sprintf sqrt srand sub substr system tolower toupper " +
 		"name string number <newline> " +
